<?php
/**
 * The template for displaying Comments.
 *
 * The area of the page that contains both current comments
 * and the comment form. The actual display of comments is
 * handled by a callback to manifest_comment() which is
 * located in the functions.php file.
 *
 * @package manifest
 * @since Manifest 2.0
 */
?>

<?php
	/*
	 * If the current post is protected by a password and
	 * the visitor has not yet entered the password we will
	 * return early without loading the comments.
	 */
	if ( post_password_required() )
		return;
?>

	<div id="comments" class="comments-area">

	<?php // You can start editing here -- including this comment! ?>

	<?php if ( have_comments() ) : ?>
		<h2 class="comments-title">
			<?php
				printf( _n( __( 'One thought on &ldquo;%2$s&rdquo;', 'manifest' ), __( '%1$s thoughts on &ldquo;%2$s&rdquo;', 'manifest'), get_comments_number(), 'manifest' ),
					number_format_i18n( get_comments_number() ), '<span>' . get_the_title() . '</span>' );
			?>
		</h2>

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through ?>
		<nav role="navigation" id="comment-nav-above" class="site-navigation comment-navigation">
			<h1 class="assistive-text"><?php _e( 'Comment navigation', 'manifest' ); ?></h1>
			<div class="nav-previous"><?php previous_comments_link( __( '&larr; Older Comments', 'manifest' ) ); ?></div>
			<div class="nav-next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'manifest' ) ); ?></div>
		</nav><!-- #comment-nav-before .site-navigation .comment-navigation -->
		<?php endif; // check for comment navigation ?>

		<ol class="commentlist">
			<?php
				/* Loop through and list the comments. Tell wp_list_comments()
				 * to use manifest_comment() to format the comments.
				 * If you want to overload this in a child theme then you can
				 * define manifest_comment() and that will be used instead.
				 * See manifest_comment() in inc/template-tags.php for more.
				 */
				wp_list_comments( array( 'callback' => 'manifest_comment' ) );
			?>
		</ol><!-- .commentlist -->

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through ?>
		<nav role="navigation" id="comment-nav-below" class="site-navigation comment-navigation">
			<h1 class="assistive-text"><?php _e( 'Comment navigation', 'manifest' ); ?></h1>
			<div class="nav-previous"><?php previous_comments_link( __( '&larr; Older Comments', 'manifest' ) ); ?></div>
			<div class="nav-next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'manifest' ) ); ?></div>
		</nav><!-- #comment-nav-below .site-navigation .comment-navigation -->
		<?php endif; // check for comment navigation ?>

	<?php endif; // have_comments() ?>

	<?php
		// If comments are closed and there are comments, let's leave a little note, shall we?
		if ( ! comments_open() && '0' != get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
	?>
		<p class="nocomments"><?php _e( 'Comments are closed.', 'manifest' ); ?></p>
	<?php endif; ?>

	<?php
	$aria_req = ( $req ? " aria-required='true'" : '' );
	$comments_args = array(
		'comment_notes_before' => '',
		'comment_notes_after' => '',

		'fields' => apply_filters( 'comment_form_default_fields', array(

			'author' =>
				'<p class="comment-form-author">' .
				'<label for="author">'. ( $req ? '<span class="required" title="Required">*</span>' : '' ) . __( 'Name', 'manifest' ) . '</label> ' .

				'<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) .
				'" size="30"' . $aria_req . ' /></p>',

			'email' =>
				'<p class="comment-form-email"><label for="email">' . ( $req ? '<span class="required" title="Required">*</span>' : '' ) . __( 'Email', 'manifest' ) . '</label> ' .
				'<input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) .
				'" size="30"' . $aria_req . ' /> <span class="help-inline">not published</span></p>',

			'url' =>
				'<p class="comment-form-url"><label for="url">' .
				__( 'Website', 'manifest' ) . '</label>' .
				' <input id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) .
				'" size="30" /></p>'
		)
		),
		'comment_field' => '<p class="comment-form-comment"><label for="comment">' . __( 'Comment', 'manifest' ) . '</label> <textarea id="comment" name="comment" aria-required="true"></textarea></p>' . 

		'<div class="form-allowed-tags">' .
		sprintf(
		__( 'Allowed <abbr title="HyperText Markup Language">HTML</abbr> tags: %s' ),
		' <code>' . allowed_tags() . '</code>'
		) . '</div>'

		,

	);
	?>
	<?php comment_form($comments_args); ?>

</div><!-- #comments .comments-area -->
